==> touhoulittlemaid-fabric-1.21.1-0.1.7.1-neo1.3.8-sources.jar: com/github/tartaricacid/touhoulittlemaid/tileentity/TileEntityJoy.java <==
package com.github.tartaricacid.touhoulittlemaid.tileentity;

import cn.sh1rocu.touhoulittlemaid.api.extension.IBlockEntityPersistentData;
import javax.annotation.Nullable;
import net.minecraft.class_156;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2487;
import net.minecraft.class_2586;
import net.minecraft.class_2591;
import net.minecraft.class_2596;
import net.minecraft.class_2602;
import net.minecraft.class_2622;
import net.minecraft.class_2680;
import net.minecraft.class_7225;
import java.util.UUID;

public abstract class TileEntityJoy extends class_2586 implements IBlockEntityPersistentData {
    private static final String SIT_ID = "SitId";
    private UUID sitId = class_156.field_25140;

    public TileEntityJoy(class_2591<?> type, class_2338 pos, class_2680 blockState) {
        super(type, pos, blockState);
    }

    @Override
    protected void method_11007(class_2487 pTag, class_7225.class_7874 pRegistries) {
        getPersistentData().method_25927(SIT_ID, this.sitId);
        super.method_11007(pTag, pRegistries);
    }

    @Override
    public void method_11014(class_2487 pTag, class_7225.class_7874 pRegistries) {
        super.method_11014(pTag, pRegistries);
        this.sitId = getPersistentData().method_25926(SIT_ID);
    }

    @Override
    public class_2487 method_16887(class_7225.class_7874 pRegistries) {
        return this.method_38244(pRegistries);
    }

    @Nullable
    @Override
    public class_2596<class_2602> method_38235() {
        return class_2622.method_38585(this);
    }

    public void refresh() {
        this.method_5431();
        if (field_11863 != null) {
            class_2680 state = field_11863.method_8320(field_11867);
            field_11863.method_8413(field_11867, state, state, class_2248.field_31036);
        }
    }

    public class_2338 getWorldPosition() {
        return this.field_11867;
    }

    public UUID getSitId() {
        return this.sitId;
    }

    public void setSitId(UUID sitId) {
        this.sitId = sitId;
    }
}

==> touhoulittlemaid-fabric-1.21.1-0.1.8-neo1.4.0-sources.jar: com/github/tartaricacid/touhoulittlemaid/tileentity/TileEntityJoy.java <==
package com.github.tartaricacid.touhoulittlemaid.tileentity;

import cn.sh1rocu.touhoulittlemaid.api.extension.IBlockEntityPersistentData;
import javax.annotation.Nullable;
import net.minecraft.class_156;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2487;
import net.minecraft.class_2586;
import net.minecraft.class_2591;
import net.minecraft.class_2596;
import net.minecraft.class_2602;
import net.minecraft.class_2622;
import net.minecraft.class_2680;
import net.minecraft.class_7225;
import java.util.UUID;

public abstract class TileEntityJoy extends class_2586 implements IBlockEntityPersistentData {
    private static final String SIT_ID = "SitId";
    private UUID sitId = class_156.field_25140;

    public TileEntityJoy(class_2591<?> type, class_2338 pos, class_2680 blockState) {
        super(type, pos, blockState);
    }

    @Override
    protected void method_11007(class_2487 pTag, class_7225.class_7874 pRegistries) {
        tlm$getPersistentData().method_25927(SIT_ID, this.sitId);
        super.method_11007(pTag, pRegistries);
    }

    @Override
    public void method_11014(class_2487 pTag, class_7225.class_7874 pRegistries) {
        super.method_11014(pTag, pRegistries);
        this.sitId = tlm$getPersistentData().method_25926(SIT_ID);
    }

    @Override
    public class_2487 method_16887(class_7225.class_7874 pRegistries) {
        return this.method_38244(pRegistries);
    }

    @Nullable
    @Override
    public class_2596<class_2602> method_38235() {
        return class_2622.method_38585(this);
    }

    public void refresh() {
        this.method_5431();
        if (field_11863 != null) {
            class_2680 state = field_11863.method_8320(field_11867);
            field_11863.method_8413(field_11867, state, state, class_2248.field_31036);
        }
    }

    public class_2338 getWorldPosition() {
        return this.field_11867;
    }

    public UUID getSitId() {
        return this.sitId;
    }

    public void setSitId(UUID sitId) {
        this.sitId = sitId;
    }
}
